@@ -98,16 +98,25 @@ import Foreign.Storable
 import GHC.Exts (Down(..))
 import GHC.Generics
 import System.IO.Unsafe
-
-#if MIN_VERSION_base(4,8,0)
 import Numeric.Natural
-#endif
 
 foreign import ccall floatToWord32 :: Float -> Word32
 foreign import ccall word32ToFloat :: Word32 -> Float
 foreign import ccall doubleToWord64 :: Double -> Word64
 foreign import ccall word64ToDouble :: Word64 -> Double
 
+-- $setup
+-- >>> import Data.Bytes.Get
+-- >>> import Data.Bytes.Put
+-- >>> import Data.Bytes.VarInt
+-- >>> import Data.Fixed
+-- >>> import Data.Ratio (Ratio, (%))
+-- >>> import Data.Time
+-- >>> import Data.Time.Clock
+-- >>> import Data.Time.Clock.TAI
+-- >>> import Data.Word
+-- >>> import Numeric.Natural
+
 ------------------------------------------------------------------------------
 -- Endianness-Dependant Serialization
 ------------------------------------------------------------------------------
@@ -279,7 +288,13 @@ store a = putByteString bs
 restore :: forall m a. (MonadGet m, Storable a) => m a
 restore = do
   let required = sizeOf (undefined :: a)
-  PS fp o n <- getByteString required
+#if MIN_VERSION_bytestring(0,11,0)
+  let o = 0
+  BS fp n
+#else
+  PS fp o n
+#endif
+    <- getByteString required
   unless (n >= required) $ MonadFail.fail "restore: Required more bytes"
   return $ unsafePerformIO $ withForeignPtr fp $ \p -> peekByteOff p o
 
@@ -393,11 +408,6 @@ getVarInt n
   | otherwise = return $ fromIntegral n
 {-# INLINE getVarInt #-}
 
--- |
--- $setup
--- >>> import Data.Word
--- >>> import Data.Fixed
--- >>> import Data.Bytes.Serial
 
 -- | Integer/Word types serialized to base-128 variable-width ints.
 --
@@ -420,14 +430,12 @@ instance Serial Integer where
   serialize = serialize . VarInt
   deserialize = unVarInt `liftM` deserialize
 
-#if MIN_VERSION_base(4,8,0)
 -- |
 -- >>> runGetL deserialize (runPutL (serialize (10^10::Natural))) :: Natural
 -- 10000000000
 instance Serial Natural where
   serialize = serialize . VarInt . toInteger
   deserialize = fromInteger . unVarInt <$> deserialize
-#endif
 
 -- |
 -- >>> (runGetL deserialize $ runPutL $ serialize (1.82::Fixed E2))::Fixed E2
